pub fn read_form_properties(
reader: &mut PageReader,
name: &str,
) -> Result<FormProperties, FileError>Expand description
Read and parse all properties from a named form or report.
Parses the Blob binary to extract form-level and per-control properties. TypeInfo is used to associate control names and type codes.